<?php
if ( ! defined( 'WPINC' ) ) {
	exit;
}
return json_decode( '{"lastScanTimestamp": 1774539630, "nextScanTimestamp": 1774576800.0, "username": "fqnewsco", "malware": [], "config": {"MALWARE_SCANNING": {"enable_scan_cpanel": true, "default_action": "cleanup"}, "PROACTIVE_DEFENCE": {"blamer": true}}, "license": {"status": true, "expiration": null, "user_limit": 2147483647, "id": "Imunify360-366548YVfHB", "user_count": 1044, "message": "", "license_type": "imunify360", "upgrade_url": null, "upgrade_url_360": null, "redirect_url": ""}}', true );