<?php
if ( ! defined( 'WPINC' ) ) {
	exit;
}
return json_decode( '{"token": "eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJleHAiOjE3NzQ4NTEwNDcsInVzZXJuYW1lIjoiZnFuZXdzY28iLCJzaXRlX3BhdGgiOiIvaG9tZS9mcW5ld3Njby9tYWdhemluZS5wcm9wZXJ0eWRheS5jb20ubmcvd3AifQ.xs5afWihjF1L6h6SoEbFxzYSvtJJAyEUly1nrbdRo1U"}', true );